@@ -22,7 +22,6 @@ use XAO::Errors qw(XAO::E::Handler);
 ##
 # Some global variables.
 #
-my $cgi=new CGI;
 my $siteconfig;
 
 ##
@@ -33,30 +32,30 @@ try {
     ##
     # Getting CGI object and path
     #
-    my $path_info=$cgi->path_info;
+    my $path_info=$ENV{'PATH_INFO'} ||
+        throw XAO::E::Handler "No PATH_INFO in the environment";
+
     my @path=split('/+','/'.$path_info);
     shift @path;
     my $sitename=shift @path;
-    $sitename || throw XAO::E::Handler "No site name given!";
+    $sitename || throw XAO::E::Handler "xao-apache.pl - no site name found";
     push @path,'' if $path_info=~/\/$/;
 
-    ##
-    # This is not very good way to check it here, should be more
-    # flexible I guess.
-    #
-    throw XAO::E::Handler "Bad file path" if grep(/^bits$/,@path);
-
-    ##
     # Loading or creating site object.
     #
-    my $site=XAO::Web->new(sitename => $sitename);
+    my $web=XAO::Web->new(sitename => $sitename);
   
-    ##
+    # Checking access control rules (path_deny_table in the config)
+    #
+    my $path=join('/','',@path);
+    $web->check_uri_access($path) ||
+        throw XAO::E::Handler "xao-apache.pl - access denied to file path '$path'";
+
     # Executing.
     #
-    my $path=join('/','/',@path);
-    $site->execute(path => $path,
-                   cgi => $cgi);
+    $web->execute(
+        path    => $path,
+    );
 }
 
 ##
@@ -65,6 +64,7 @@ try {
 #
 otherwise {
     my $e=shift;
+    my $cgi=new CGI;
     print $cgi->header(-status => "500 System Error"),
           $cgi->start_html("System error"),
           $cgi->h1("System error"),
