@@ -23,20 +23,35 @@ use XAO::Errors qw(XAO::DO::Web::CgiParam);
 use base XAO::Objects->load(objname => 'Web::Page');
 
 use vars qw($VERSION);
-$VERSION=(0+sprintf('%u.%03u',(q$Id: CgiParam.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+$VERSION='2.2';
+### $VERSION=(0+sprintf('%u.%03u',(q$Id: CgiParam.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
 sub display ($;%) {
     my $self=shift;
     my $args=get_args(\@_);
 
-    my $name=$args->{name} || $args->{param} ||
-        throw XAO::E::DO::Web::CgiParam "display - no 'param' and no 'name' given";
+    my $name=$args->{'name'} || $args->{'param'} ||
+        throw $self "- no 'param' and no 'name' given";
 
     my $text;
     $text=$self->cgi->param($name);
-    $text=$args->{default} unless defined $text;
+    $text=$args->{'default'} unless defined $text;
+
     return unless defined $text;
 
+    # Preventing XSS attacks. Unless we have a 'dont_sanitize' parameter
+    # angle brackets are removed from the output.
+    #
+    if(!$args->{'dont_sanitize'}) {
+        $text=~s/[<>]/ /sg;
+    }
+
+    # Trimming spaces
+    #
+    if(!$args->{'keep_spaces'}) {
+        $text=~s/^\s*|\s*$//sg;
+    }
+
     $self->textout($text);
 }
 
