@@ -62,7 +62,7 @@ Site configuration parameter.
 
 =item cookie
 
-Cookie value.
+Cookie value (including cookie values set earlier in the same render).
 
 =item secure
 
@@ -84,7 +84,25 @@ use XAO::Objects;
 use base XAO::Objects->load(objname => 'Web::Page');
 
 use vars qw($VERSION);
-$VERSION=(0+sprintf('%u.%03u',(q$Id: Condition.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+$VERSION=(0+sprintf('%u.%03u',(q$Id: Condition.pm,v 2.9 2008/07/08 03:41:48 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+
+###############################################################################
+
+sub check_target ($$$) {
+    my ($pvalue,$target,$targop)=@_;
+
+    if(defined $target && defined $pvalue) {
+        if($targop eq '=')      { return ($pvalue eq $target); }
+        elsif($targop eq '!')   { return ($pvalue ne $target); }
+        elsif($targop eq '<')   { return ($pvalue < $target); }
+        elsif($targop eq '>')   { return ($pvalue > $target); }
+    }
+    else {
+        return $pvalue;
+    }
+}
+
+###############################################################################
 
 sub display ($;%)
 { my $self=shift;
@@ -100,18 +118,16 @@ sub display ($;%)
      if($2 eq 'cgiparam')
       { my $param=$args{$a};
         my $cname=$1;
-        if($param =~ /\s*(.*?)\s*=\s*(.*?)\s*$/)
-         { my $pval=$config->cgi->param($1);
-           if(defined($pval) && $pval eq $2)
-            { $name=$cname;
-              last;
-            }
+        my ($target,$targop);
+        if($param =~ /^\s*(.*?)\s*(=|>|<|\!)\s*(.*?)\s*$/)
+         { $param=$1;
+           $targop=$2;
+           $target=$3;
          }
-        else
-         { if($config->cgi->param($param))
-            { $name=$cname;
-              last;
-            }
+        my $pvalue=$config->cgi->param($param);
+        if(check_target($pvalue,$target,$targop))
+         { $name=$cname;
+           last;
          }
       }
      elsif($2 eq 'length')
@@ -122,38 +138,77 @@ sub display ($;%)
          }
       }
      elsif($2 eq 'arg')
-      { if($self->{parent} && $self->{parent}->{args}->{$args{$a}})
-         { $name=$1;
-           last;
+      { my $param=$args{$a};
+        my $cname=$1;
+        my ($target,$targop);
+        if($param =~ /^\s*(.*?)\s*(=|>|<|\!)\s*(.*?)\s*$/)
+         { $param=$1;
+           $targop=$2;
+           $target=$3;
+         }
+        if($self->{'parent'})
+         { my $pvalue=$self->{'parent'}->{'args'}->{$param};
+           my $matches;
+           if(check_target($pvalue,$target,$targop))
+            { $name=$cname;
+              last;
+            }
          }
       }
      elsif($2 eq 'siteconf' || $2 eq 'siteconfig')
-      { if($config->get($args{$a}))
-         { $name=$1;
+      { my $param=$args{$a};
+        my $cname=$1;
+        my ($target,$targop);
+        if($param =~ /^\s*(.*?)\s*(=|>|<|\!)\s*(.*?)\s*$/)
+         { $param=$1;
+           $targop=$2;
+           $target=$3;
+         }
+        my $pvalue=$config->get($param);
+        if(check_target($pvalue,$target,$targop))
+         { $name=$cname;
            last;
          }
       }
      elsif($2 eq 'cookie')
-      {  if($config->cgi->cookie($args{$a}))
-          { $name=$1;
-             last;
-          }    
+      { my $param=$args{$a};
+        my $cname=$1;
+        my ($target,$targop);
+        if($param =~ /^\s*(.*?)\s*(=|>|<|\!)\s*(.*?)\s*$/)
+         { $param=$1;
+           $targop=$2;
+           $target=$3;
+         }
+        my $pvalue=$config->get_cookie($param);
+        if(check_target($pvalue,$target,$targop))
+         { $name=$cname;
+           last;
+         }
       }
      elsif($2 eq 'number')
       { if(($args{$a} || 0)+0)
          { $name=$1;
            last;
-         }    
+         }
       }
      elsif($2 eq 'secure')
       { if($self->is_secure)
          { $name=$1;
            last;
-         }    
+         }
       }
      elsif($2 eq 'clipboard')
-      { if($self->clipboard->get($args{$a}))
-         { $name=$1;
+      { my $param=$args{$a};
+        my $cname=$1;
+        my ($target,$targop);
+        if($param =~ /^\s*(.*?)\s*(=|>|<|\!)\s*(.*?)\s*$/)
+         { $param=$1;
+           $targop=$2;
+           $target=$3;
+         }
+        my $pvalue=$self->clipboard->get($param);
+        if(check_target($pvalue,$target,$targop))
+         { $name=$cname;
            last;
          }
       }
@@ -164,14 +219,13 @@ sub display ($;%)
    }
     $name="default" unless defined $name;
 
-    ##
     # Building object arguments now.
     #
     my %objargs;
     foreach my $a (keys %args) {
-        if($self->{parent} && $self->{parent}->{args}
-                           && $a =~ /^$name\.pass\.(.*)$/) {
-            $objargs{$1}=$self->{parent}->{args}->{$1};
+        if($self->{'parent'} && $self->{'parent'}->{'args'}
+                             && $a =~ /^$name\.pass\.(.*)$/) {
+            $objargs{$1}=$self->{'parent'}->{'args'}->{$1};
         }
         elsif($a eq "$name.pass") {
             # See below
@@ -182,20 +236,15 @@ sub display ($;%)
     }
     return unless %objargs;
 
-    ##
     # Now getting the object
     #
-    my $obj=$self->object(objname => $objargs{objname} || "Page");
-    delete $objargs{objname};
+    my $obj=$self->object(objname => $objargs{'objname'} || "Page");
+    delete $objargs{'objname'};
 
-    ##
     # If we were asked to pass complete set of arguments then merging.
     #
-    if($args{"$name.pass"} && $self->{parent} && $self->{parent}->{args}) {
-        my $aaa=merge_refs($self->{parent}->{args});
-        delete $aaa->{path};
-        delete $aaa->{template};
-        $obj->display(merge_refs($aaa,\%objargs));
+    if($args{"$name.pass"}) {
+        $obj->display($self->pass_args($args{"$name.pass"},\%objargs));
     }
     else {
         $obj->display(\%objargs);
