@@ -29,25 +29,37 @@ use XAO::Objects;
 use base XAO::Objects->load(objname => 'Web::Page');
 
 use vars qw($VERSION);
-$VERSION=(0+sprintf('%u.%03u',(q$Id: Default.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+$VERSION=(0+sprintf('%u.%03u',(q$Id: Default.pm,v 2.3 2006/05/23 20:17:35 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
 ###############################################################################
 
 =item display (%)
 
-Takes only one argument - file path and displays
-/bits/errors/file-not-found template providing that path as a FILEPATH
-argument.
+Normally takes no arguments and uses /pagedesc/fullpath to pass to
+/bits/errors/file-not-found template as a FILEPATH argument.
+
+Sets up page headers to show 404 page not found message.
 
 =cut
 
-sub display ($%) {
+sub display ($@) {
     my $self=shift;
     my $args=get_args(\@_);
-    my $config=$self->siteconfig;
-    $config->header_args(-Status => '404 File not found');
-    $self->SUPER::display(path => '/bits/errors/file-not-found',
-                          FILEPATH => $args->{path} || '');
+
+    my $path=$self->clipboard->get('/pagedesc/fullpath') ||
+        $args->{'path'} ||
+        '';
+
+    $self->siteconfig->header_args(
+        -Status         => '404 File not found',
+        -expires        => 'now',
+        -cache_control  => 'no-cache',
+    );
+
+    $self->object->display(
+        path        => '/bits/errors/file-not-found',
+        FILEPATH    => $path,
+    );
 }
 
 ###############################################################################
